
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.29.8',
    'branch_nick': 'release-1.29-LTS',
    'revision_id': 'dab34ec995148c6daf72c429c442794ed2b551cc',
    'revno': 12088
}
